@@ -1,10 +1,12 @@
 """Cells module of kfactory."""
 
+from ._demopdk import demo  # noqa: I001
 from . import bezier, circular, euler, straight, taper, virtual
 
 __all__ = [
     "bezier",
     "circular",
+    "demo",
     "euler",
     "straight",
     "taper",
