@@ -1,8 +1,8 @@
 """Virtual euler cells."""
 
 from ...factories.virtual.euler import virtual_bend_euler_factory
-from ...layout import kcl
+from .. import demo
 
 __all__ = ["virtual_bend_euler"]
 
-virtual_bend_euler = virtual_bend_euler_factory(kcl)
+virtual_bend_euler = virtual_bend_euler_factory(kcl=demo)
