@@ -51,6 +51,7 @@ if TYPE_CHECKING:
     from collections.abc import Callable, Iterable, Sequence
 
     from .layout import KCLayout
+    from .schematic import DSchematic, Schematic
 
 
 def _parse_params(
@@ -172,15 +173,22 @@ def _check_instances(
     match check_instances:
         case CheckInstances.RAISE:
             if any(inst.is_complex() for inst in cell.each_inst()):
+                instance_names = [
+                    inst.name for inst in cell.each_inst() if inst.is_complex()
+                ]
+                cell_names = [
+                    inst.cell.name for inst in cell.each_inst() if inst.is_complex()
+                ]
+                affected = "\n".join(
+                    f"Instance name: {iname}, Cell name: {cname}"
+                    for iname, cname in zip(instance_names, cell_names, strict=True)
+                )
                 raise ValueError(
                     "Found off-grid instances, which is not allowed in most "
                     "foundries.\n"
                     "Please run c.flatten() before returning "
                     "or add use @cell(check_instances=False).\n"
-                    "Cellnames of instances affected by this: "
-                    + "\n".join(
-                        inst.cell.name for inst in cell.each_inst() if inst.is_complex()
-                    )
+                    f"Instances affected by this:\n{affected}"
                 )
         case CheckInstances.FLATTEN:
             if any(inst.is_complex() for inst in cell.each_inst()):
@@ -315,22 +323,14 @@ def _post_process(
 class WrappedKCellFunc(Generic[KCellParams, KC]):
     _f: Callable[KCellParams, KC]
     _f_orig: Callable[KCellParams, ProtoTKCell[Any]]
+    _f_schematic: Callable[KCellParams, Schematic | DSchematic] | None = None
     cache: Cache[int, KC] | dict[int, Any]
     name: str
     kcl: KCLayout
     output_type: type[KC]
     lvs_equivalent_ports: list[list[str]] | None = None
     ports_definition: PortsDefinition | None = None
-
-    @property
-    def __name__(self) -> str:
-        if self.name is None:
-            raise ValueError(f"{self._f} does not have a name")
-        return self.name
-
-    @__name__.setter
-    def __name__(self, value: str) -> None:
-        self.name = value
+    tags: set[str]
 
     def __init__(
         self,
@@ -356,11 +356,13 @@ class WrappedKCellFunc(Generic[KCellParams, KC]):
         debug_names: bool,
         lvs_equivalent_ports: list[list[str]] | None = None,
         ports: PortsDefinition | None = None,
+        tags: Sequence[str] | None = None,
     ) -> None:
         self.kcl = kcl
         self.output_type = output_type
-        self.name = _get_function_name(f)
+        self.name = basename or _get_function_name(f)
         self.ports_definition = ports.copy() if ports is not None else None
+        self.tags = set(tags) if tags else set()
 
         @functools.wraps(f)
         def wrapper_autocell(
@@ -577,16 +579,7 @@ class WrappedVKCellFunc(Generic[KCellParams, VK]):
     output_type: type[VK]
     lvs_equivalent_ports: list[list[str]] | None = None
     ports_definition: PortsDefinition | None = None
-
-    @property
-    def __name__(self) -> str:
-        if self.name is None:
-            raise ValueError(f"{self._f} does not have a name")
-        return self.name
-
-    @__name__.setter
-    def __name__(self, value: str) -> None:
-        self.name = value
+    tags: set[str]
 
     def __init__(
         self,
@@ -607,11 +600,13 @@ class WrappedVKCellFunc(Generic[KCellParams, VK]):
         post_process: Iterable[Callable[[VKCell], None]],
         lvs_equivalent_ports: list[list[str]] | None = None,
         ports: PortsDefinition | None = None,
+        tags: Sequence[str] | None = None,
     ) -> None:
         self.kcl = kcl
         self.output_type = output_type
-        self.name = _get_function_name(f)
+        self.name = basename or _get_function_name(f)
         self.ports_definitions = ports.copy() if ports is not None else None
+        self.tags = set(tags) if tags else set()
 
         @functools.wraps(f)
         def wrapper_autocell(
