@@ -76,7 +76,7 @@ def bend_s_bezier_factory(
     Args:
         kcl: The KCLayout which will be owned
         additional_info: Add additional key/values to the
-            [`KCell.info`][kfactory.kcell.KCell.info]. Can be a static dict
+            [`KCell.info`][kfactory.settings.Info]. Can be a static dict
             mapping info name to info value. Or can a callable which takes the straight
             functions' parameters as kwargs and returns a dict with the mapping.
         basename: Overwrite the prefix of the resulting KCell's name. By default
