@@ -55,7 +55,7 @@ def virtual_bend_euler_factory(
     Args:
         kcl: The KCLayout which will be owned
         additional_info: Add additional key/values to the
-            [`VKCell.info`][kfactory.kcell.VKCell.info]. Can be a static dict
+            [`VKCell.info`][kfactory.settings.Info]. Can be a static dict
             mapping info name to info value. Or can a callable which takes the straight
             functions' parameters as kwargs and returns a dict with the mapping.
         basename: Overwrite the prefix of the resulting VKCell's name. By default
@@ -101,7 +101,7 @@ def virtual_bend_euler_factory(
             angle: Angle of the bend.
             resolution: Angle resolution for the backbone.
         """
-        c = VKCell()
+        c = kcl.vkcell()
         if angle < 0:
             logger.critical(
                 f"Negative lengths are not allowed {angle} as ports"
