@@ -2,13 +2,27 @@ from __future__ import annotations
 
 import functools
 import inspect
-from collections import UserDict, defaultdict
-from collections.abc import Callable, Iterable, Sequence  # noqa: TC003
+from collections import defaultdict
+from collections.abc import (
+    Callable,
+    Iterable,
+    Iterator,
+    Mapping,
+    Sequence,
+)
 from functools import cached_property
 from pathlib import Path
 from pprint import pformat
 from threading import RLock
-from typing import TYPE_CHECKING, Any, Concatenate, Literal, cast, overload
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Concatenate,
+    Generic,
+    Literal,
+    cast,
+    overload,
+)
 
 import ruamel.yaml
 from cachetools import Cache
@@ -61,9 +75,9 @@ from .typings import (
     KC,
     KCIN,
     VK,
+    F,
     KC_contra,
     KCellParams,
-    KCellSpec,
     MetaData,
     P,
     T,
@@ -73,7 +87,7 @@ from .utilities import load_layout_options, save_layout_options
 
 if TYPE_CHECKING:
     from .ports import DPorts, Ports
-    from .schema import TSchema
+    from .schematic import TSchematic
 
 kcl: KCLayout
 kcls: dict[str, KCLayout] = {}
@@ -92,31 +106,86 @@ def get_default_kcl() -> KCLayout:
     return kcl
 
 
-class Factories(UserDict[str, T]):
-    tags: dict[str, list[T]]
+class Factories(Mapping[str, F], Generic[F]):
+    _all: list[F]
+    _by_name: dict[str, int]
+    _by_tag: defaultdict[str, list[int]]
+    _by_function: dict[Callable[..., Any], int]
 
-    def __init__(self, data: dict[str, T]) -> None:
-        super().__init__(data)
-        self.tags = defaultdict(list)
+    def __init__(self) -> None:
+        self._all = []
+        self._by_name = {}
+        self._by_tag = defaultdict(list)
+        self._by_function = {}
 
-    def __getattr__(self, name: str) -> Any:
-        if name != "data":
-            try:
-                return self.data[name]
-            except KeyError as e:
-                try:
-                    return self.__getattribute__(name)
-                except AttributeError:
-                    raise KeyError from e
-        return self.__getattribute__(name)
+    def add(self, factory: F) -> None:
+        idx = len(self._all)
+        self._all.append(factory)
+        for tag in factory.tags:
+            self._by_tag[tag].append(idx)
+        self._by_name[factory.name] = idx
+        self._by_function[factory.__call__] = idx
 
-    def for_tags(self, tags: list[str]) -> list[T]:
-        if len(tags) > 0:
-            tag_set = set(self.tags[tags[0]])
-            for tag in tags[1:]:
-                tag_set &= set(self.tags[tag])
-            return list(tag_set)
-        raise NotImplementedError
+    def get_by_name(self, name: str) -> F:
+        return self._all[self._by_name[name]]
+
+    def is_unique(self) -> bool:
+        return len(self._all) == len(self._by_name)
+
+    def rebuild(self) -> None:
+        self._by_name = {}
+        self._by_tag = defaultdict(list)
+        self._by_function = {}
+
+        for idx, factory in enumerate(self._all):
+            for tag in factory.tags:
+                self._by_tag[tag].append(idx)
+            self._by_name[factory.name] = idx
+            self._by_function[factory.__call__] = idx
+
+    def get_by_tag(self, tag: str) -> list[F]:
+        return [self._all[idx] for idx in self._by_tag[tag]]
+
+    def __iter__(self) -> Iterator[str]:
+        return iter(self._by_name)
+
+    def __len__(self) -> int:
+        return len(self._by_name)
+
+    def __contains__(self, key: Any) -> bool:
+        if isinstance(key, str):
+            return key in self._by_name
+        return key in self._all
+
+    def __getitem__(self, key: str) -> F:
+        try:
+            return self._all[self._by_name[key]]
+        except KeyError as e:
+            from rapidfuzz import process
+
+            results = pformat(
+                [
+                    result[0]
+                    for result in process.extract(
+                        key, list(self._by_name.keys()), limit=10
+                    )
+                ]
+            )
+
+            raise KeyError(
+                f"Unknown Factory {key!r}, closest 10 name matches: {results}"
+            ) from e
+
+    @overload
+    def get(self, key: str, /) -> F | None: ...
+
+    @overload
+    def get(self, key: str, /, default: T) -> F | T: ...
+
+    def get(self, key: str, /, default: T | None = None) -> F | T | None:
+        if key in self._by_name:
+            return self.get_by_name(key)
+        return default
 
 
 class KCLayout(
@@ -274,8 +343,8 @@ class KCLayout(
             enclosure=KCellEnclosure([]),
             infos=infos_,
             layers=LayerEnum,
-            factories=Factories({}),
-            virtual_factories=Factories({}),
+            factories=Factories[WrappedKCellFunc[Any, ProtoTKCell[Any]]](),
+            virtual_factories=Factories[WrappedVKCellFunc[Any, VKCell]](),
             sparameters_path=sparameters_path,
             interconnect_cml_path=interconnect_cml_path,
             constants=constants_,
@@ -433,7 +502,8 @@ class KCLayout(
             if allow_undefined_layers:
                 return self.layout.layer(info)
             raise KeyError(
-                f"Layer '{args=}, {kwargs=}' has not been defined in the KCLayout."
+                f"Layer '{args=}, {kwargs=}' has not been defined in the KCLayout. "
+                "Have you defined the layer and set it in KCLayout.info?"
             ) from e
 
     @overload
@@ -536,7 +606,7 @@ class KCLayout(
     @overload
     def schematic_cell(
         self,
-        _func: Callable[KCellParams, TSchema[TUnit]],
+        _func: Callable[KCellParams, TSchematic[TUnit]],
         /,
     ) -> Callable[KCellParams, KCell]: ...
 
@@ -561,8 +631,26 @@ class KCLayout(
         info: dict[str, MetaData] | None = ...,
         debug_names: bool | None = ...,
         tags: list[str] | None = ...,
+        factories: Mapping[
+            str, Callable[..., KCell] | Callable[..., DKCell] | Callable[..., VKCell]
+        ]
+        | None = None,
+        cross_sections: Mapping[str, CrossSection | DCrossSection] | None = None,
+        routing_strategies: dict[
+            str,
+            Callable[
+                Concatenate[
+                    ProtoTKCell[Any],
+                    Sequence[ProtoPort[Any]],
+                    Sequence[ProtoPort[Any]],
+                    ...,
+                ],
+                Any,
+            ],
+        ]
+        | None = None,
     ) -> Callable[
-        [Callable[KCellParams, TSchema[TUnit]]], Callable[KCellParams, KCell]
+        [Callable[KCellParams, TSchematic[TUnit]]], Callable[KCellParams, KCell]
     ]: ...
 
     @overload
@@ -587,8 +675,26 @@ class KCLayout(
         post_process: Iterable[Callable[[KCell], None]],
         debug_names: bool | None = ...,
         tags: list[str] | None = ...,
+        factories: Mapping[
+            str, Callable[..., KCell] | Callable[..., DKCell] | Callable[..., VKCell]
+        ]
+        | None = None,
+        cross_sections: Mapping[str, CrossSection | DCrossSection] | None = None,
+        routing_strategies: dict[
+            str,
+            Callable[
+                Concatenate[
+                    ProtoTKCell[Any],
+                    Sequence[ProtoPort[Any]],
+                    Sequence[ProtoPort[Any]],
+                    ...,
+                ],
+                Any,
+            ],
+        ]
+        | None = None,
     ) -> Callable[
-        [Callable[KCellParams, TSchema[TUnit]]], Callable[KCellParams, KCell]
+        [Callable[KCellParams, TSchematic[TUnit]]], Callable[KCellParams, KCell]
     ]: ...
 
     @overload
@@ -614,8 +720,26 @@ class KCLayout(
         post_process: Iterable[Callable[[KCell], None]],
         debug_names: bool | None = ...,
         tags: list[str] | None = ...,
+        factories: Mapping[
+            str, Callable[..., KCell] | Callable[..., DKCell] | Callable[..., VKCell]
+        ]
+        | None = None,
+        cross_sections: Mapping[str, CrossSection | DCrossSection] | None = None,
+        routing_strategies: dict[
+            str,
+            Callable[
+                Concatenate[
+                    ProtoTKCell[Any],
+                    Sequence[ProtoPort[Any]],
+                    Sequence[ProtoPort[Any]],
+                    ...,
+                ],
+                Any,
+            ],
+        ]
+        | None = None,
     ) -> Callable[
-        [Callable[KCellParams, TSchema[TUnit]]], Callable[KCellParams, KC]
+        [Callable[KCellParams, TSchematic[TUnit]]], Callable[KCellParams, KC]
     ]: ...
 
     @overload
@@ -640,13 +764,31 @@ class KCLayout(
         info: dict[str, MetaData] | None = ...,
         debug_names: bool | None = ...,
         tags: list[str] | None = ...,
+        factories: Mapping[
+            str, Callable[..., KCell] | Callable[..., DKCell] | Callable[..., VKCell]
+        ]
+        | None = None,
+        cross_sections: Mapping[str, CrossSection | DCrossSection] | None = None,
+        routing_strategies: dict[
+            str,
+            Callable[
+                Concatenate[
+                    ProtoTKCell[Any],
+                    Sequence[ProtoPort[Any]],
+                    Sequence[ProtoPort[Any]],
+                    ...,
+                ],
+                Any,
+            ],
+        ]
+        | None = None,
     ) -> Callable[
-        [Callable[KCellParams, TSchema[TUnit]]], Callable[KCellParams, KC]
+        [Callable[KCellParams, TSchematic[TUnit]]], Callable[KCellParams, KC]
     ]: ...
 
     def schematic_cell(
         self,
-        _func: Callable[KCellParams, TSchema[TUnit]] | None = None,
+        _func: Callable[KCellParams, TSchematic[TUnit]] | None = None,
         /,
         *,
         output_type: type[KC] | None = None,
@@ -667,14 +809,32 @@ class KCLayout(
         post_process: Iterable[Callable[[KCell], None]] | None = None,
         debug_names: bool | None = None,
         tags: list[str] | None = None,
+        factories: Mapping[
+            str, Callable[..., KCell] | Callable[..., DKCell] | Callable[..., VKCell]
+        ]
+        | None = None,
+        cross_sections: Mapping[str, CrossSection | DCrossSection] | None = None,
+        routing_strategies: dict[
+            str,
+            Callable[
+                Concatenate[
+                    ProtoTKCell[Any],
+                    Sequence[ProtoPort[Any]],
+                    Sequence[ProtoPort[Any]],
+                    ...,
+                ],
+                Any,
+            ],
+        ]
+        | None = None,
     ) -> (
         Callable[KCellParams, KCell]
         | Callable[
-            [Callable[KCellParams, TSchema[Any]]],
+            [Callable[KCellParams, TSchematic[Any]]],
             Callable[KCellParams, KC],
         ]
         | Callable[
-            [Callable[KCellParams, TSchema[Any]]],
+            [Callable[KCellParams, TSchematic[Any]]],
             Callable[KCellParams, KCell],
         ]
     ):
@@ -682,7 +842,7 @@ class KCLayout(
             if output_type is None:
 
                 def wrap_f(
-                    f: Callable[KCellParams, TSchema[TUnit]],
+                    f: Callable[KCellParams, TSchematic[TUnit]],
                 ) -> Callable[KCellParams, KCell]:
                     @self.cell(
                         output_type=KCell,
@@ -708,15 +868,24 @@ class KCLayout(
                     def kcell_func(
                         *args: KCellParams.args, **kwargs: KCellParams.kwargs
                     ) -> KCell:
-                        schema = f(*args, **kwargs)
-                        return schema.create_cell(KCell)
+                        schematic = f(*args, **kwargs)
+                        if set_name:
+                            schematic.name = self.future_cell_name
+                        c_ = schematic.create_cell(
+                            KCell,
+                            factories=factories,
+                            cross_sections=cross_sections,
+                            routing_strategies=routing_strategies,
+                        )
+                        c_.schematic = schematic
+                        return c_
 
                     return kcell_func
 
                 return wrap_f
 
             def custom_wrap_f(
-                f: Callable[KCellParams, TSchema[TUnit]],
+                f: Callable[KCellParams, TSchematic[TUnit]],
             ) -> Callable[KCellParams, KC]:
                 @self.cell(
                     output_type=output_type,
@@ -742,23 +911,41 @@ class KCLayout(
                 def custom_kcell_func(
                     *args: KCellParams.args, **kwargs: KCellParams.kwargs
                 ) -> KCell:
-                    schema = f(*args, **kwargs)
-                    return schema.create_cell(KCell)
+                    schematic = f(*args, **kwargs)
+                    if set_name:
+                        schematic.name = self.future_cell_name
+                    c_ = schematic.create_cell(
+                        KCell,
+                        factories=factories,
+                        cross_sections=cross_sections,
+                        routing_strategies=routing_strategies,
+                    )
+                    c_.schematic = schematic
+                    return c_
 
                 return custom_kcell_func
 
             return custom_wrap_f
 
         def simple_wrap_f(
-            f: Callable[KCellParams, TSchema[TUnit]],
+            f: Callable[KCellParams, TSchematic[TUnit]],
         ) -> Callable[KCellParams, KCell]:
             @functools.wraps(f)
-            @self.cell
+            @self.cell(output_type=KCell)
             def kcell_func(
                 *args: KCellParams.args, **kwargs: KCellParams.kwargs
             ) -> KCell:
-                schema = f(*args, **kwargs)
-                return schema.create_cell(KCell)
+                schematic = f(*args, **kwargs)
+                if set_name:
+                    schematic.name = self.future_cell_name
+                c_ = schematic.create_cell(
+                    KCell,
+                    factories=factories,
+                    cross_sections=cross_sections,
+                    routing_strategies=routing_strategies,
+                )
+                c_.schematic = schematic
+                return c_
 
             return kcell_func
 
@@ -932,8 +1119,7 @@ class KCLayout(
                 ignored.
             snap_ports: Snap the centers of the ports onto the grid
                 (only x/y, not angle).
-            add_port_layers: Add special layers of
-                [netlist_layer_mapping][kfactory.kcell.KCLayout.netlist_layer_mapping]
+            add_port_layers: Add special layers of `KCLayout.netlist_layer_mapping`
                 to the ports if the port layer is in the mapping.
             cache: Provide a user defined cache instead of an internal one. This
                 can be used for example to clear the cache.
@@ -943,7 +1129,7 @@ class KCLayout(
             drop_params: Drop these parameters before writing the
                 [settings][kfactory.kcell.KCell.settings]
             register_factory: Register the resulting KCell-function to the
-                [factories][kfactory.kcell.KCLayout.factories]
+                `KCLayout.factories`
             layout_cache: If true, treat the layout like a cache, if a cell with the
                 same name exists already, pick that one instead of using running the
                 function. This only works if `set_name` is true. Can be globally
@@ -955,9 +1141,7 @@ class KCLayout(
             post_process: List of functions to call after the cell has been created.
             debug_names: Check on setting the name whether a cell with this name already
                 exists.
-            tags: Tag cell functions with user defined tags. With this, cell functions
-                can then be retrieved with `kcl.factories.tags[my_tag]` or if filtered
-                for multiple `kcl.factories.for_tags([my_tag1, my_tag2, ...])`.
+            tags: Tag cell functions with user defined tags.
         Returns:
             A wrapped cell function which caches responses and modifies the cell
             according to settings.
@@ -1018,10 +1202,7 @@ class KCLayout(
                 with self.thread_lock:
                     if wrapper_autocell.name is None:
                         raise ValueError(f"Function {f} has no name.")
-                    if tags:
-                        for tag in tags:
-                            self.factories.tags[tag].append(wrapper_autocell)  # type: ignore[arg-type]
-                    self.factories[basename or wrapper_autocell.name] = wrapper_autocell  # type: ignore[assignment]
+                    self.factories.add(wrapper_autocell)  # type: ignore[arg-type]
 
             @functools.wraps(f)
             def func(*args: KCellParams.args, **kwargs: KCellParams.kwargs) -> KC:
@@ -1118,21 +1299,16 @@ class KCLayout(
                 string created from the args/kwargs
             check_ports: Check uniqueness of port names.
             check_pins: Check uniqueness of pin names.
-            snap_ports: Snap the centers of the ports onto the grid
-                (only x/y, not angle).
-            add_port_layers: Add special layers of
-                [netlist_layer_mapping][kfactory.kcell.KCLayout.netlist_layer_mapping]
+            add_port_layers: Add special layers of `KCLayout.netlist_layer_mapping`
                 to the ports if the port layer is in the mapping.
             cache: Provide a user defined cache instead of an internal one. This
                 can be used for example to clear the cache.
-            rec_dicts: Allow and inspect recursive dictionaries as parameters (can be
-                expensive if the cell is called often).
             basename: Overwrite the name normally inferred from the function or class
                 name.
             drop_params: Drop these parameters before writing the
                 [settings][kfactory.kcell.KCell.settings]
             register_factory: Register the resulting KCell-function to the
-                [factories][kfactory.kcell.KCLayout.factories]
+                `KCLayout.factories`
             info: Additional metadata to put into info attribute.
             post_process: List of functions to call after the cell has been created.
         Returns:
@@ -1182,12 +1358,7 @@ class KCLayout(
             if register_factory:
                 if wrapper_autocell.name is None:
                     raise ValueError(f"Function {f} has no name.")
-                if tags:
-                    for tag in tags:
-                        self.factories.tags[tag].append(wrapper_autocell)  # type: ignore[arg-type]
-                self.virtual_factories[basename or wrapper_autocell.name] = (
-                    wrapper_autocell  # type: ignore[assignment]
-                )
+                self.virtual_factories.add(wrapper_autocell)  # type: ignore[arg-type]
 
             @functools.wraps(f)
             def func(*args: KCellParams.args, **kwargs: KCellParams.kwargs) -> VK:
@@ -1313,7 +1484,8 @@ class KCLayout(
             if allow_duplicate or (self.layout_cell(name) is None):
                 return self.layout.create_cell(name, *args)
             raise ValueError(
-                f"Cellname {name} already exists. Please make sure the cellname is"
+                f"Cellname {name} already exists in the layout/KCLayout. "
+                "Please make sure the cellname is"
                 " unique or pass `allow_duplicate` when creating the library"
             )
 
@@ -1381,7 +1553,7 @@ class KCLayout(
                 self.tkcells[kcell.cell_index()] = kcell.base
             else:
                 raise ValueError(
-                    "Cannot register a new cell with a name that already"
+                    f"Cannot register {kcell} if it has been registered already"
                     " exists in the library"
                 )
 
@@ -1393,7 +1565,12 @@ class KCLayout(
         """
         return self.get_cell(obj)
 
-    def get_cell(self, obj: str | int, cell_type: type[KC] = KCell) -> KC:  # type: ignore[assignment]
+    def get_cell(
+        self,
+        obj: str | int,
+        cell_type: type[KC] = KCell,  # type: ignore[assignment]
+        error_search_limit: int | None = 10,
+    ) -> KC:
         """Retrieve a cell by name(str) or index(int).
 
         Attrs:
@@ -1401,6 +1578,7 @@ class KCLayout(
             cell_type: type of cell to return
         """
         if isinstance(obj, int):
+            # search by index
             try:
                 return cell_type(base=self.tkcells[obj])
             except KeyError:
@@ -1408,15 +1586,33 @@ class KCLayout(
                 if kdb_c is None:
                     raise
                 return cell_type(name=kdb_c.name, kcl=self, kdb_cell=kdb_c)
-        else:
-            kdb_c = self.layout_cell(obj)
-            if kdb_c is not None:
-                try:
-                    return cell_type(base=self.tkcells[kdb_c.cell_index()])
-                except KeyError:
-                    c = cell_type(name=kdb_c.name, kcl=self, kdb_cell=kdb_c)
-                    c.get_meta_data()
-                    return c
+        # search by name/key
+        kdb_c = self.layout_cell(obj)
+        if kdb_c is not None:
+            try:
+                return cell_type(base=self.tkcells[kdb_c.cell_index()])
+            except KeyError:
+                c = cell_type(name=kdb_c.name, kcl=self, kdb_cell=kdb_c)
+                c.get_meta_data()
+                return c
+        if error_search_limit:
+            # limit the print of available cells
+            # and throw closest names with fuzzy search
+            from rapidfuzz import process
+
+            closest_names = [
+                result[0]
+                for result in process.extract(
+                    obj,
+                    (cell.name for cell in self.kcells.values()),
+                    limit=error_search_limit,
+                )
+            ]
+            raise ValueError(
+                f"Library doesn't have a KCell named {obj},"
+                f" closest {error_search_limit} are: \n"
+                f"{pformat(closest_names)}"
+            )
 
         raise ValueError(
             f"Library doesn't have a KCell named {obj},"
@@ -1519,7 +1715,11 @@ class KCLayout(
                     raise MergeError(err_msg)
 
             cells = set(self.cells("*"))
-            binary_layout = layout_b.write_bytes(save_layout_options())
+            saveopts = save_layout_options()
+            saveopts.gds2_max_cellname_length = (
+                kdb.SaveLayoutOptions().gds2_max_cellname_length
+            )
+            binary_layout = layout_b.write_bytes(saveopts)
             locked_cells = [
                 kdb_cell for kdb_cell in self.layout.each_cell() if kdb_cell.locked
             ]
@@ -1751,60 +1951,6 @@ class KCLayout(
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({self.name}, n={len(self.kcells)})"
 
-    @overload
-    def get_component(
-        self, spec: KCellSpec, *, output_type: type[KC], **cell_kwargs: Any
-    ) -> KC: ...
-
-    @overload
-    def get_component(
-        self,
-        spec: int,
-    ) -> KCell: ...
-
-    @overload
-    def get_component(
-        self,
-        spec: str,
-        **cell_kwargs: Any,
-    ) -> ProtoTKCell[Any]: ...
-
-    @overload
-    def get_component(
-        self,
-        spec: Callable[..., KC],
-        **cell_kwargs: Any,
-    ) -> KC: ...
-    @overload
-    def get_component(self, spec: KC) -> KC: ...
-
-    def get_component(
-        self,
-        spec: KCellSpec,
-        *,
-        output_type: type[KC] | None = None,
-        **cell_kwargs: Any,
-    ) -> ProtoTKCell[Any]:
-        """Get a component by specification."""
-        if output_type:
-            return output_type(base=self.get_component(spec, **cell_kwargs).base)
-        if callable(spec):
-            return spec(**cell_kwargs)
-        if isinstance(spec, dict):
-            settings = spec.get("settings", {}).copy()
-            settings.update(cell_kwargs)
-            return self.factories[spec["component"]](**settings)
-        if isinstance(spec, str):
-            if spec in self.factories:
-                return self.factories[spec](**cell_kwargs)
-            return self[spec]
-        if cell_kwargs:
-            raise ValueError(
-                "Cell kwargs are not allowed for retrieving static cells by integer "
-                "or the cell itself."
-            )
-        return self.kcells[spec] if isinstance(spec, int) else spec
-
     def delete(self) -> None:
         del kcls[self.name]
         self.library.delete()
