@@ -1,7 +1,13 @@
+from collections.abc import Callable
+from typing import Any
+
 import kfactory as kf
 
 
-def test_pack_kcells(kcl: kf.KCLayout) -> None:
+def test_pack_kcells(
+    kcl: kf.KCLayout,
+    oasis_regression: Callable[[kf.ProtoTKCell[Any]], None],
+) -> None:
     c = kcl.kcell()
     straight = kf.factories.straight.straight_dbu_factory(kcl)(
         width=1000, length=1000, layer=kf.kdb.LayerInfo(1, 0)
@@ -10,9 +16,13 @@ def test_pack_kcells(kcl: kf.KCLayout) -> None:
         c, [straight] * 4, max_height=2000, max_width=2000
     )
     assert instance_group.bbox() == kf.kdb.DBox(0, 0, 2000, 2000)
+    oasis_regression(c)
 
 
-def test_pack_instances(kcl: kf.KCLayout) -> None:
+def test_pack_instances(
+    kcl: kf.KCLayout,
+    oasis_regression: Callable[[kf.ProtoTKCell[Any]], None],
+) -> None:
     c = kcl.kcell()
     straight = kf.factories.straight.straight_dbu_factory(kcl)(
         width=1000, length=1000, layer=kf.kdb.LayerInfo(1, 0)
@@ -25,3 +35,4 @@ def test_pack_instances(kcl: kf.KCLayout) -> None:
         c, [ref, ref2, ref3, ref4], max_height=2000, max_width=2000
     )
     assert instance_group.bbox() == kf.kdb.DBox(0, 0, 2000, 2000)
+    oasis_regression(c)
